@@ -114,18 +114,7 @@ Returns an array of strings representing all stream URLs found.
 =item $podcast->B<getURL>([I<options>])
 
 Similar to B<get>() except it only returns a single stream representing 
-the first valid stream found.  
-
-Current options are:  I<"random">, I<"nopls">, and I<"noplaylists">.  
-By default, the first ("best"?) stream is returned.  If I<"random"> is 
-specified, then a random one is selected from the list of streams found.  
-If I<"nopls"> is specified, and the stream to be returned is a ".pls" playlist, 
-it is first fetched and the first entry (or a random entry if I<"random"> is 
-specified) is returned.  This is needed by Fauxdacious Mediaplayer.
-If I<"noplaylists"> is specified, and the stream to be returned is a 
-"playlist" (either .pls or .m3u? extension), it is first fetched and the first 
-entry (or a random entry if I<"random"> is specified) in the playlist 
-is returned.
+the first valid stream found.  There currently are no valid I<options>.
 
 =item $podcast->B<count>()
 
